@@ -79,7 +79,7 @@ LockScreen::LockScreen()
         LsWidget::setPortrait(false);
     } else if (orientation == "portrait"){
         m_View->setAttribute(Qt::WA_Maemo5PortraitOrientation);        
-        m_WasPortrait = true;
+        m_WasPortrait = false;
         LsWidget::setPortrait(true);
     }else{
         m_View->setAttribute(Qt::WA_Maemo5AutoOrientation);
@@ -87,9 +87,21 @@ LockScreen::LockScreen()
                      MCE_SIGNAL_PATH,
                      MCE_SIGNAL_IF,
                      MCE_DEVICE_ORIENTATION_SIG, this, SLOT(onOrientationChanged(QDBusMessage)));
+
+        LsWidget::setPortrait(isPortrait());
+        m_WasPortrait = !LsWidget::isPortrait();
     }
 
     m_View->setAttribute(Qt::WA_Maemo5NonComposited);
+#else
+    QString orientation = QSettings().value("Main/Orientation", "auto").toString().toLower();
+    if (orientation == "portrait"){
+        m_WasPortrait = false;
+        LsWidget::setPortrait(true);
+    }else{
+        m_WasPortrait = false;
+        LsWidget::setPortrait(false);
+    }
 #endif    
 
     setHildonFlags();
@@ -136,11 +148,11 @@ bool LockScreen::show()
         return false;
 
 #ifdef Q_WS_MAEMO_5
-    m_View->showFullScreen();
-    setSizeAndPosition();
+    m_View->showFullScreen();    
 #else
     m_View->show();
 #endif
+    setSizeAndPosition();
     m_View->update(m_View->rect());
     return true;
 }
@@ -340,11 +352,13 @@ void LockScreen::setSizeAndPosition()
         m_WasPortrait = isPortrait;
 
         qDebug() << "Orientation changed portrait=" << isPortrait;
-
-        if (isPortrait)
-            m_Scene.setSceneRect(0, 0, 480, 800);
-        else
+        if (isPortrait){
+            m_Scene.setSceneRect(0, 0, 480, 800);        
+            m_View->setFixedSize(480, 800);
+        }else{
             m_Scene.setSceneRect(0, 0, 800, 480);
+            m_View->setFixedSize(800, 480);
+        }
         setBackground();
 
         foreach(QGraphicsItem* item, m_Scene.items()){
@@ -378,3 +392,23 @@ bool LockScreen::isLocked()
 #endif
     return res;
 }
+
+bool LockScreen::isPortrait()
+{
+    bool res = false;
+#ifdef Q_WS_MAEMO_5
+    QDBusConnection conn = QDBusConnection::systemBus();
+    QDBusInterface device(MCE_SERVICE,
+                          MCE_REQUEST_PATH, MCE_REQUEST_IF, conn);
+    QDBusMessage msg = device.call(MCE_DEVICE_ORIENTATION_GET);
+
+    if (msg.arguments().count() > 0 ){
+        QString state = msg.arguments()[0].toString();
+        qDebug() << "Portrait:" << state;
+        res = state == "portrait";
+    }
+#else
+    res = false;
+#endif
+    return res;
+}
