@@ -67,11 +67,14 @@ int main(int argc, char *argv[])
         QDir().mkpath(pathInfo.path());
 
     //Always copy the default current settings:
-    QFile().copy(":/DefaultSettings.conf", QString("%1.default").arg(name));
+    QString def = QString("%1.default").arg(name);
+    if (QFile::exists(def))
+        QFile::remove(def);
+    QFile::copy(":/DefaultSettings.conf", QString("%1.default").arg(name));
 
     //Copy the default settings if the file does not exists.
-    if (!QFile().exists(name))
-        QFile().copy(":/DefaultSettings.conf", name);
+    if (!QFile::exists(name))
+        QFile::copy(":/DefaultSettings.conf", name);
 
     //Translation:
     QString locale = QLocale::system().name();
