@@ -72,7 +72,7 @@ void LsBattery::applySettings()
 {
     setSizeAndPosition(QSize(64, 40),QPoint(0, 0));
     QString images = getSetting("Images",
-                                ":/images/battery_0.png;:/images/battery_1.png;:/images/battery_2.png;:/images/battery_3.png;:/images/battery_4.png;:/images/battery_5.png;:/images/battery_6.png").toString();
+                                "/opt/qtlockscreen/default/battery_0.png;/opt/qtlockscreen/default/battery_1.png;/opt/qtlockscreen/default/battery_2.png;/opt/qtlockscreen/default/battery_3.png;/opt/qtlockscreen/default/battery_4.png;/opt/qtlockscreen/default/battery_5.png;/opt/qtlockscreen/default/battery_6.png").toString();
 
     m_Images.clear();
     foreach (QString img, images.split(';')){
@@ -81,7 +81,7 @@ void LsBattery::applySettings()
             m_Images.append(i);
     }
 
-    m_ChargingImage = QPixmap(getSetting("ChargingImage", ":/images/battery_charging.png").toString());
+    m_ChargingImage = QPixmap(getSetting("ChargingImage", "/opt/qtlockscreen/default/battery_charging.png").toString());
     m_PercColor = getColorSetting("PercentageColor", QColor(255,255,255));
     m_PercFont = getFontSetting("PercentageFont", QFont("", 15, QFont::Normal, false));
 }
