@@ -45,8 +45,11 @@ void LsSlideToUnlock::applySettings()
     m_Slider->setPos(m_SliderInitialPos);
     m_BackgroundImage = QPixmap(getSetting("BackgroundImage", "").toString());
 
-    m_UnlockX = getSetting("UnlockX", -1).toInt();
-    m_UnlockY = getSetting("UnlockY", -1).toInt();
+    //m_UnlockX = getSetting("UnlockX", -1).toInt();
+    //m_UnlockY = getSetting("UnlockY", -1).toInt();
+    m_UnlockX = -1;
+    m_UnlockY = -1;
+    onOrientationChanged();
     setSizeAndPosition(QSize(100, 100), QPoint(0, 0));
 }
 
@@ -75,3 +78,14 @@ void LsSlideToUnlock::onSliderMoved(QPointF pos)
     #endif
     }
 }
+
+void LsSlideToUnlock::onOrientationChanged()
+{
+    if (LsWidget::isPortrait()){
+        m_UnlockX = getSetting("UnlockXP", m_UnlockX).toInt();
+        m_UnlockY = getSetting("UnlockYP", m_UnlockY).toInt();
+    }else{
+        m_UnlockX = getSetting("UnlockXL", m_UnlockX).toInt();
+        m_UnlockY = getSetting("UnlockYL", m_UnlockY).toInt();
+    }
+}
