@@ -48,11 +48,8 @@ QPoint LsWidget::getPosSetting(QString name, QPoint defaultValue)
     QString pos = getSetting(name, "").toString();
     QStringList elem = pos.split(';');
     if (elem.count() == 2){        
-#ifdef Q_WS_MAEMO_5
         QSize s = LsWidget::isPortrait() ? QSize(480, 800) : QSize(800, 480);
-#else
-        QSize s(800,480);
-#endif
+
         int x = 0;
         int y = 0;
         if (elem.at(0) == "center")
